@@ -71,8 +71,9 @@ struct _GstMpeg2dec {
   /* video state */
   GstVideoCodecState *input_state;
   GstVideoInfo        decoded_info;
-  gboolean       need_cropping;
-  gboolean       has_cropping;
+  GstVideoAlignment   valign;
+  GstBufferPool *     downstream_pool;
+  gboolean            need_alignment;
 
   guint8        *dummybuf[4];
 };
@@ -82,6 +83,7 @@ struct _GstMpeg2decClass {
 };
 
 GType gst_mpeg2dec_get_type(void);
+GST_ELEMENT_REGISTER_DECLARE (mpeg2dec);
 
 G_END_DECLS
 
